@@ -11,15 +11,15 @@
 #' set.seed(42)
 #' df <- data.frame(x = runif(100), y = sample(c("A", "B"), 100, TRUE))
 #' confint_t(df$x)
-confint_t <- function(x, alpha = 0.05, na.rm = TRUE){
+confint_t <- function(x, alpha = 0.05, na.rm = TRUE) {
   if (!is.numeric(x)) {
     stop("Data is not a numeric vector")
   }
 
-  alpha    <- alpha/2
-  sd       <- sd(x, na.rm = na.rm)
-  w_krit   <- qt(1 - (alpha), df = (length(na.omit(x)) - 1))
-  width    <- w_krit * sd/sqrt(length(na.omit(x)))
+  alpha <- alpha / 2
+  sd <- sd(x, na.rm = na.rm)
+  w_krit <- qt(1 - (alpha), df = (length(na.omit(x)) - 1))
+  width <- w_krit * sd / sqrt(length(na.omit(x)))
 
   return(width)
 }
@@ -38,15 +38,15 @@ confint_t <- function(x, alpha = 0.05, na.rm = TRUE){
 #' set.seed(42)
 #' df <- data.frame(x = runif(100), y = sample(c("A", "B"), 100, TRUE))
 #' mean_ci_t(df$x)
-mean_ci_t <- function(x, alpha = 0.05, na.rm = TRUE){
+mean_ci_t <- function(x, alpha = 0.05, na.rm = TRUE) {
   if (!is.numeric(x)) {
     stop("Data is not a numeric vector")
   }
 
-  m     <- mean(x, na.rm = na.rm)
+  m <- mean(x, na.rm = na.rm)
   upper <- m + confint_t(x = x, alpha = alpha, na.rm = na.rm)
   lower <- m - confint_t(x = x, alpha = alpha, na.rm = na.rm)
-  ret   <- data.frame(y = m, ymin = lower, ymax = upper)
+  ret <- data.frame(y = m, ymin = lower, ymax = upper)
 
   return(ret)
 }
@@ -67,17 +67,19 @@ mean_ci_sem <- function(x, conf.level = .95) {
     stop("Data is not a numeric vector")
   }
   # SEM if sigma is known // todo: add option or correct for length(x) and NAs
-  sem  <- sd(x, na.rm = TRUE) / sqrt(length(na.omit(x)))
+  sem <- sd(x, na.rm = TRUE) / sqrt(length(na.omit(x)))
   # clvl <- qnorm(1 - conf.level / 2)
   clvl <- qnorm(conf.level + ((1 - conf.level) / 2))
 
   CI_upper <- mean(x, na.rm = TRUE) + (sem * clvl)
   CI_lower <- mean(x, na.rm = TRUE) - (sem * clvl)
 
-  bunch_of_stats <- data.frame(y    = mean(x, na.rm = TRUE),
-                               SEM  = sem,
-                               ymin = CI_lower,
-                               ymax = CI_upper)
+  bunch_of_stats <- data.frame(
+    y = mean(x, na.rm = TRUE),
+    SEM = sem,
+    ymin = CI_lower,
+    ymax = CI_upper
+  )
 
   return(bunch_of_stats)
 }
@@ -90,16 +92,16 @@ mean_ci_sem <- function(x, conf.level = .95) {
 #' set.seed(42)
 #' df <- data.frame(x = runif(100), y = sample(c("A", "B"), 100, TRUE))
 #' confint_norm(df$x)
-confint_norm <- function(x, alpha = 0.05, na.rm = TRUE){
+confint_norm <- function(x, alpha = 0.05, na.rm = TRUE) {
   if (!is.numeric(x)) {
     stop("Data is not a numeric vector")
   }
 
-  alpha    <- alpha/2
-  sd       <- sd(x, na.rm = na.rm)
-  sem      <- sd/sqrt(length(na.omit(x)))
-  w_krit   <- qnorm(1 - (alpha), mean = mean(x, na.rm = na.rm), sd = sem)
-  width    <- w_krit * sem
+  alpha <- alpha / 2
+  sd <- sd(x, na.rm = na.rm)
+  sem <- sd / sqrt(length(na.omit(x)))
+  w_krit <- qnorm(1 - (alpha), mean = mean(x, na.rm = na.rm), sd = sem)
+  width <- w_krit * sem
 
   return(width)
 }
