@@ -14,7 +14,7 @@
 #' @importFrom broom tidy
 #' @import pixiedust
 #' @family Tadaa-functions
-#' @seealso [tadaa_pairwise_t()], [tadaa_pairwise_gh()]
+#' @seealso [tadaa_pairwise_t()]
 #' @examples
 #' tadaa_pairwise_tukey(data = ngo, deutsch, jahrgang, geschl)
 #' tadaa_pairwise_tukey(data = ngo, deutsch, jahrgang, print = "console")
@@ -23,7 +23,7 @@ tadaa_pairwise_tukey <- function(data, response, group1, group2 = NULL, print =
   group1 <- deparse(substitute(group1))
   group2 <- deparse(substitute(group2))
 
-  if (group2 == "NULL") {
+  if (is.null(group2)) {
     formula <- as.formula(paste0(response, " ~ ", group1))
   } else {
     formula <- as.formula(paste0(response, " ~ ", group1, " * ", group2))
@@ -33,6 +33,11 @@ tadaa_pairwise_tukey <- function(data, response, group1, group2 = NULL, print =
   tukey <- stats::TukeyHSD(model, ...)
   tukey <- broom::tidy(tukey)
 
+  if (utils::hasName(tukey, "comparison")) {
+    tukey$contrast <- tukey$comparison
+    tukey$comparison <- NULL
+  }
+
   if (print == "df") {
     return(tukey)
   } else {
@@ -45,7 +50,8 @@ tadaa_pairwise_tukey <- function(data, response, group1, group2 = NULL, print =
       adj.p.value = "p (adj.)",
       estimate = "Diff",
       term = "Term",
-      comparison = "Comparison",
+      # comparison = "Comparison", # old broom
+      contrast = "Comparison", # new broom
       conf.low = "CI_low",
       conf.high = "CI_high"
     )
@@ -57,3 +63,5 @@ tadaa_pairwise_tukey <- function(data, response, group1, group2 = NULL, print =
 
   pixiedust::sprinkle_print_method(output, print_method = print)
 }
+
+globalVariables("tukey") # but why though
