@@ -1,10 +1,5 @@
 context("Tadaa, Assumptions!")
 
-test_that("tadaa_normtest works", {
-  expect_is(tadaa_normtest(ngo[c("deutsch", "englisch")], method = "pearson", print = "console"), "dust")
-  expect_is(tadaa_normtest(ngo[c("deutsch", "englisch")], method = "pearson", print = "markdown"), "dust")
-  expect_is(tadaa_normtest(ngo[c("deutsch", "englisch")], method = "pearson", print = "df"), "data.frame")
-})
 
 test_that("tadaa_levene works", {
   expect_is(tadaa_levene(ngo, deutsch ~ jahrgang * geschl, print = "console"), "dust")
